import request from "@/util/oaRequest"

// 查询物流预览列表
export function listExpress(query) {
  return request({
    url: '/oa/express/list',
    method: 'get',
    params: query
  })
}

// 查询物流预览详细
export function getExpress(expressId) {
  return request({
    url: '/oa/express/' + expressId,
    method: 'get'
  })
}
// 查询物流预览详细
export function refreshExpress(expressId) {
  return request({
    url: '/oa/express/refresh/' + expressId,
    method: 'get'
  })
}

// 新增物流预览
export function addExpress(data) {
  return request({
    url: '/oa/express',
    method: 'post',
    data: data
  })
}

// 修改物流预览
export function updateExpress(data) {
  return request({
    url: '/oa/express',
    method: 'put',
    data: data
  })
}

// 删除物流预览
export function delExpress(expressId) {
  return request({
    url: '/oa/express/' + expressId,
    method: 'delete'
  })
}
